<?php
namespace Controller;

use Service\Traits\TResponse;
use Service\DeleteCascadeService;
use Service\TemplateJson;
use Util\Utilities;
use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DataSource\DataSet;
use \Service\Manager\Mongo\Manager;

class ViewType extends Crud {
    
    use TResponse;

	protected $dataSourceName = 'viewType';
	/** @var \Service\ViewType $viewTypeService */
	protected $viewTypeService;

	public function __construct(Manager $mongoManager, DeleteCascadeService $deleteCascadeService, \Service\ViewType $viewTypeService) {
		parent::__construct($mongoManager, $deleteCascadeService);
		$this->viewTypeService = $viewTypeService;
	}

	public function findAllWithProperties(Request\Filter $request, Response $response) {
		try {
			$response->addDataSet(new DataSet('viewType', $this->viewTypeService->findAllWithDimensionAndFactProperties()));
		} catch (\Exception $e) {
			$response->setError(new Response\Error($e->getMessage(), $e->getCode()));
		}
	}

    public function find(Request\Filter $request, Response $response)
    {
        try {
            $dataSet = TemplateJson::getViewType();
            Utilities::setDataSetDefault($request, $response, $dataSet);

        } catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }

    public function findNext(Request $request, Response $response)
    {
        try {
            $dataSet = TemplateJson::getViewType();
            $this->sendResponse(Utilities::parseDataSourceZeedhiNext($dataSet), 200);

        } catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }

}
