<?php
namespace Service;

use Service\Manager\Mongo\Manager;
use Util\Utilities;
use Zeedhi\Framework\DataSource\Manager\Doctrine\NameProvider;
use Zmart\Mongo\Mongo;
use Zeedhi\Zmart\DataSource\ZmartFilterCriteria;
use Zeedhi\Zmart\QueryBuilders\Mongo\QueryBuilder;

class DefaultOrganizationManagerFactory {

	public static function createDefaultOrgManager(Manager $manager, NameProvider $nameProvider, QueryBuilder $queryBuilder) {
        $mongos = self::buildMongoFromDefaultOrgConnection($manager);
        $managers = array();
        $manager = null;
        
        foreach ($mongos as $dbLabel=>$mongo) {
            $manager = new Manager($mongo, $nameProvider, $queryBuilder);
            $managers[$dbLabel] = $manager;
        }
        
        return $managers;
	}

     protected static function buildMongoFromDefaultOrgConnection(Manager $manager) {
        $baseConnections = Utilities::getEnvironment()->getBaseConnection();
        $mongo = null;
        $mongoDbs = array();
        if (!empty($baseConnections)) {
            foreach($baseConnections as $baseConnection){
                $host = $baseConnection['host'];
                $port = $baseConnection['port'];
                $dbName = $baseConnection['dbName'];
                $dbLabel = $baseConnection['dbLabel'];
                $options = array();
                if (isset($baseConnection['username']) && isset($baseConnection['password'])) {
                    $options['username'] = $baseConnection['username'];
                    $options['password'] = $baseConnection['password'];
                }

                $mongo = new Mongo($host, $port, null, $options);
                $mongo->setDbByName($dbName);
                $mongoDbs[$dbLabel] = $mongo;
            }
        }

        return $mongoDbs;
    }
}