import {ChartViewInterface} from "@/Services/ChartView/ChartViewInterface";
import {ChartViewAbstract} from "@/Services/ChartView/ChartViewAbstract";
import {ZmartChartsApex} from "@/Services/Chats/ZmartChartsApex";

export class Grid extends ChartViewAbstract implements ChartViewInterface {
    public hasMultipleDimensions: Boolean = true;

    public getWidget(dashboard: any, widget: any) {
        const height = widget[0].style;
        if ((dashboard.label !== '' || dashboard.label !== null) && widget[0].children && widget[0].children.length > 0) {
            widget[0].children[0].text = dashboard.label;
        }
        widget[0].style = "background: " + dashboard.color + "; " + height;
        return widget;
    }

    protected applyStyles(gridStyles: any, column: any, row: any) {
        if (gridStyles) {
            let cssClasse: string = '';
            gridStyles.forEach((style: any) => {
                if (this.columnCompare(column, style.styleFields) && this.evalCondition(style.condition, row)) {
                    cssClasse = style.cssClass;
                }
            });
            return cssClasse;
        }
        return {};
    }

    protected columnCompare(column: any, styles: any) {
        if (Array.isArray(column)) {
            return column.some((element: any) => styles.includes(element));
        }
        return styles.includes(column);
    }

    public checkAppliedCustomCss(styleName: string): boolean {
        return !!document.getElementById("Zmart_custom_" + styleName);
    }

    public addcss(styleName: string, cssCode: string) {
        if (!this.checkAppliedCustomCss(styleName)) {
            const style = document.createElement('style');
            style.type = 'text/css';
            style.innerHTML = cssCode;
            style.id = "Zmart_custom_" + styleName;
            document.getElementsByTagName('head')[0].appendChild(style);
        }
    }

    public conditionsCustomCssStyles(gridStyle: any, eventNext: any) {
        const row = eventNext.row;
        const cellName = eventNext.column.name;
        return this.applyStyles(gridStyle, cellName, row);
    }

    public getCharts(charts: any) {
        if (charts[0].widget.gridStyle) {
            charts[0].widget.gridStyle.forEach((style: any) => {
                this.addcss(style.styleName, style.css.cssCode);
            });
            charts[0].columns.forEach((field: any) => {
                field.conditions.cssClass = this.conditionsCustomCssStyles.bind(this, charts[0].widget.gridStyle);
            });
        }
        return charts;
    }

    public setDrill(charts: any, zmartCharts: ZmartChartsApex) {
        this.getZmartCharts().setGridFormatterFunctions(charts);
        this.zmartCharts = zmartCharts;
        charts[0].events = {
            "rowClick": this.getZmartCharts().drillGrid.bind(this.getZmartCharts(), charts[0].widget),
        };
        return charts;
    }
}
